@@ -1,13 +1,13 @@
 /*
-$Id: di.h,v 1.23 2006-09-15 13:52:31-07 bll Exp $
+$Id: di.h,v 1.25 2007-05-30 10:26:41-07 bll Exp $
 $Source: /export/home/bll/DI/RCS/di.h,v $
-Copyright 1994-2004 Brad Lanam, Walnut Creek, CA
+Copyright 1994-2007 Brad Lanam, Walnut Creek, CA
 */
 
 #ifndef __INC_DI_H_
 #define __INC_DI_H_
 
-/* $Id: di.h,v 1.23 2006-09-15 13:52:31-07 bll Exp $ */
+/* $Id: di.h,v 1.25 2007-05-30 10:26:41-07 bll Exp $ */
 
 #include "config.h"
 
@@ -131,11 +131,11 @@ typedef struct
     char            fsType [DI_TYPE_LEN + 1];       /* type of file system  */
     char            options [DI_OPT_LEN + 1];
     char            mountTime [DI_MNT_TIME_LEN + 1];
-} di_DiskInfo;
+} diDiskInfo_t;
 
-extern int  di_getDiskEntries      _((di_DiskInfo **, int *));
-extern void di_getDiskInfo         _((di_DiskInfo **, int *));
-extern void di_testRemoteDisk      _((di_DiskInfo *));
+extern int  di_getDiskEntries      _((diDiskInfo_t **, int *));
+extern void di_getDiskInfo         _((diDiskInfo_t **, int *));
+extern void di_testRemoteDisk      _((diDiskInfo_t *));
 extern void *Realloc               _((void *, Size_t));
 
 /* workaround for cygwin                                              */
