@@ -1,7 +1,7 @@
 /*
-$Id: dilib.c,v 1.34 2006-10-04 23:51:52-07 bll Exp $
+$Id: dilib.c,v 1.36 2007-05-30 10:26:44-07 bll Exp $
 $Source: /export/home/bll/DI/RCS/dilib.c,v $
-Copyright 1994-2006 Brad Lanam, Walnut Creek, CA
+Copyright 1994-2007 Brad Lanam, Walnut Creek, CA
 */
 
 /********************************************************/
@@ -192,8 +192,8 @@ Copyright 1994-2006 Brad Lanam, Walnut Creek, CA
 #  define MNT_NOCACHE M_NOCACHE
 # endif
 
-static void convertMountOptions _((long, di_DiskInfo *));
-static void convertNFSMountOptions _((long, long, long, di_DiskInfo *));
+static void convertMountOptions _((long, diDiskInfo_t *));
+static void convertNFSMountOptions _((long, long, long, diDiskInfo_t *));
 static void trimChar _((char *, int));
 #if _lib_getmntent && \
 	! defined (_lib_mntctl)
@@ -293,14 +293,14 @@ int di_lib_debug = { 0 };
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     status_t        stat;
     int             idx;
     int32           count;
@@ -323,10 +323,10 @@ di_getDiskEntries (diskInfo, diCount)
 
         idx = *diCount;
         ++*diCount;
-        *diskInfo = (di_DiskInfo *) Realloc ((char *) *diskInfo,
-                sizeof (di_DiskInfo) * *diCount);
+        *diskInfo = (diDiskInfo_t *) Realloc ((char *) *diskInfo,
+                sizeof (diDiskInfo_t) * *diCount);
         diptr = *diskInfo + idx;
-        memset ((char *) diptr, '\0', sizeof (di_DiskInfo));
+        memset ((char *) diptr, '\0', sizeof (diDiskInfo_t));
         diptr->printFlag = DI_PRNT_OK;
         *buff = '\0';
         nref.device = dev;
@@ -382,14 +382,14 @@ static char *checkMountOptions _((struct mnttab *, char *));
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     FILE            *f;
     int             idx;
     struct mnttab   mntEntry;
@@ -408,10 +408,10 @@ di_getDiskEntries (diskInfo, diCount)
     {
         idx = *diCount;
         ++*diCount;
-        *diskInfo = (di_DiskInfo *) Realloc ((char *) *diskInfo,
-                sizeof (di_DiskInfo) * *diCount);
+        *diskInfo = (diDiskInfo_t *) Realloc ((char *) *diskInfo,
+                sizeof (diDiskInfo_t) * *diCount);
         diptr = *diskInfo + idx;
-        memset ((char *) diptr, '\0', sizeof (di_DiskInfo));
+        memset ((char *) diptr, '\0', sizeof (diDiskInfo_t));
         diptr->printFlag = DI_PRNT_OK;
         diptr->isLocal = TRUE;
         diptr->isReadOnly = FALSE;
@@ -527,14 +527,14 @@ chkMountOptions (mntopts, str)
 
 void
 # if _proto_stdc
-di_getDiskInfo (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskInfo (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             i;
     Statvfs_t       statBuf;
 
@@ -619,10 +619,10 @@ di_getDiskInfo (diskInfo, diCount)
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
@@ -647,9 +647,9 @@ di_getDiskEntries (diskInfo, diCount)
         {
             idx = *diCount;
             ++*diCount;
-            *diskInfo = (di_DiskInfo *) Realloc ((char *) *diskInfo,
-                    sizeof (di_DiskInfo) * *diCount);
-            memset ((char *) diptr, '\0', sizeof (di_DiskInfo));
+            *diskInfo = (diDiskInfo_t *) Realloc ((char *) *diskInfo,
+                    sizeof (diDiskInfo_t) * *diCount);
+            memset ((char *) diptr, '\0', sizeof (diDiskInfo_t));
             diptr->printFlag = DI_PRNT_OK;
             diptr->isLocal = TRUE;
             diptr->isReadOnly = FALSE;
@@ -700,14 +700,14 @@ di_getDiskEntries (diskInfo, diCount)
 
 void
 # if _proto_stdc
-di_getDiskInfo (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskInfo (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             i;
     struct statfs   statBuf;
 
@@ -789,14 +789,14 @@ di_getDiskInfo (diskInfo, diCount)
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     FILE            *f;
     int             idx;
     struct mntent   *mntEntry;
@@ -818,10 +818,10 @@ di_getDiskEntries (diskInfo, diCount)
     {
         idx = *diCount;
         ++*diCount;
-        *diskInfo = (di_DiskInfo *) Realloc ((char *) *diskInfo,
-                sizeof (di_DiskInfo) * *diCount);
+        *diskInfo = (diDiskInfo_t *) Realloc ((char *) *diskInfo,
+                sizeof (diDiskInfo_t) * *diCount);
         diptr = *diskInfo + idx;
-        memset ((char *) diptr, '\0', sizeof (di_DiskInfo));
+        memset ((char *) diptr, '\0', sizeof (diDiskInfo_t));
         diptr->printFlag = DI_PRNT_OK;
         diptr->isLocal = TRUE;
         diptr->isReadOnly = FALSE;
@@ -897,14 +897,14 @@ di_getDiskEntries (diskInfo, diCount)
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             count;
     int             idx;
     int             len;
@@ -920,13 +920,13 @@ di_getDiskEntries (diskInfo, diCount)
     }
 
     *diCount = count;
-    *diskInfo = (di_DiskInfo *) malloc (sizeof (di_DiskInfo) * count);
-    if (*diskInfo == (di_DiskInfo *) NULL)
+    *diskInfo = (diDiskInfo_t *) malloc (sizeof (diDiskInfo_t) * count);
+    if (*diskInfo == (diDiskInfo_t *) NULL)
     {
         fprintf (stderr, "malloc failed for diskInfo. errno %d\n", errno);
         return -1;
     }
-    memset ((char *) *diskInfo, '\0', sizeof (di_DiskInfo) * count);
+    memset ((char *) *diskInfo, '\0', sizeof (diDiskInfo_t) * count);
 
     if (di_lib_debug > 1)
     {
@@ -1185,14 +1185,14 @@ di_getDiskEntries (diskInfo, diCount)
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             count;
     int             idx;
     long            bufsize;
@@ -1212,13 +1212,13 @@ di_getDiskEntries (diskInfo, diCount)
     count = getfsstat (mntbufp, bufsize, MNT_NOWAIT);
 
     *diCount = count;
-    *diskInfo = (di_DiskInfo *) malloc (sizeof (di_DiskInfo) * count);
-    if (*diskInfo == (di_DiskInfo *) NULL)
+    *diskInfo = (diDiskInfo_t *) malloc (sizeof (diDiskInfo_t) * count);
+    if (*diskInfo == (diDiskInfo_t *) NULL)
     {
         fprintf (stderr, "malloc failed for diskInfo. errno %d\n", errno);
         return -1;
     }
-    memset ((char *) *diskInfo, '\0', sizeof (di_DiskInfo) * count);
+    memset ((char *) *diskInfo, '\0', sizeof (diDiskInfo_t) * count);
 
     for (idx = 0; idx < count; idx++)
     {
@@ -1314,14 +1314,14 @@ di_getDiskEntries (diskInfo, diCount)
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             count;
     int             idx;
     long            bufsize;
@@ -1341,13 +1341,13 @@ di_getDiskEntries (diskInfo, diCount)
     count = getvfsstat (mntbufp, bufsize, ST_NOWAIT);
 
     *diCount = count;
-    *diskInfo = (di_DiskInfo *) malloc (sizeof (di_DiskInfo) * count);
-    if (*diskInfo == (di_DiskInfo *) NULL)
+    *diskInfo = (diDiskInfo_t *) malloc (sizeof (diDiskInfo_t) * count);
+    if (*diskInfo == (diDiskInfo_t *) NULL)
     {
         fprintf (stderr, "malloc failed for diskInfo. errno %d\n", errno);
         return -1;
     }
-    memset ((char *) *diskInfo, '\0', sizeof (di_DiskInfo) * count);
+    memset ((char *) *diskInfo, '\0', sizeof (diDiskInfo_t) * count);
 
     for (idx = 0; idx < count; idx++)
     {
@@ -1433,14 +1433,14 @@ di_getDiskEntries (diskInfo, diCount)
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             count;
     int             bufsize;
     int             idx;
@@ -1471,14 +1471,14 @@ di_getDiskEntries (diskInfo, diCount)
     }
 
     *diCount = count;
-    *diskInfo = (di_DiskInfo *) malloc (sizeof (di_DiskInfo) * count);
-    if (*diskInfo == (di_DiskInfo *) NULL)
+    *diskInfo = (diDiskInfo_t *) malloc (sizeof (diDiskInfo_t) * count);
+    if (*diskInfo == (diDiskInfo_t *) NULL)
     {
         fprintf (stderr, "malloc failed for diskInfo. errno %d\n", errno);
         free ((char *) fsdbuf);
         return -1;
     }
-    memset ((char *) *diskInfo, '\0', sizeof (di_DiskInfo) * count);
+    memset ((char *) *diskInfo, '\0', sizeof (diDiskInfo_t) * count);
 
     for (idx = 0; idx < count; idx++)
     {
@@ -1584,14 +1584,14 @@ static char *AIX_fsType [NUM_AIX_FSTYPES] =
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             num;        /* number of vmount structs returned    */
     char            *vmbuf;     /* buffer for vmount structs returned   */
     int             vmbufsz;    /* size in bytes of vmbuf               */
@@ -1650,8 +1650,8 @@ di_getDiskEntries (diskInfo, diCount)
 
         /* <num> vmount structs returned in vmbuf */
     *diCount = num;
-    *diskInfo = (di_DiskInfo *) calloc (sizeof (di_DiskInfo), *diCount);
-    if (*diskInfo == (di_DiskInfo *) NULL)
+    *diskInfo = (diDiskInfo_t *) calloc (sizeof (diDiskInfo_t), *diCount);
+    if (*diskInfo == (diDiskInfo_t *) NULL)
     {
         fprintf (stderr, "malloc failed for diskInfo. %s errno %d\n",
                  strerror (errno), errno);
@@ -1743,14 +1743,14 @@ di_getDiskEntries (diskInfo, diCount)
 
 void
 # if _proto_stdc
-di_getDiskInfo (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskInfo (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             i;
     struct statfs   statBuf;
 
@@ -1811,14 +1811,14 @@ di_getDiskInfo (diskInfo, diCount)
 
 int
 # if _proto_stdc
-di_getDiskEntries (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskEntries (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskEntries (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo     *diptr;
+    diDiskInfo_t     *diptr;
     int             i;
     int             diskflag;
     int             rc;
@@ -1837,8 +1837,8 @@ di_getDiskEntries (diskInfo, diCount)
     rc = GetLogicalDriveStrings (MSDOS_BUFFER_SIZE, buff);
     *diCount = rc / BYTES_PER_LOGICAL_DRIVE;
 
-    *diskInfo = (di_DiskInfo *) calloc (sizeof (di_DiskInfo), *diCount);
-    if (*diskInfo == (di_DiskInfo *) NULL)
+    *diskInfo = (diDiskInfo_t *) calloc (sizeof (diDiskInfo_t), *diCount);
+    if (*diskInfo == (diDiskInfo_t *) NULL)
     {
         fprintf (stderr, "malloc failed for diskInfo. errno %d\n", errno);
         return -1;
@@ -1892,14 +1892,14 @@ di_getDiskEntries (diskInfo, diCount)
 
 void
 # if _proto_stdc
-di_getDiskInfo (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
 # else
 di_getDiskInfo (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 # endif
 {
-    di_DiskInfo         *diptr;
+    diDiskInfo_t         *diptr;
     int                 i;
     int                 rc;
     char                volName [MSDOS_BUFFER_SIZE];
@@ -2043,11 +2043,11 @@ Realloc (ptr, size)
 
 static void
 #if _proto_stdc
-convertMountOptions (long flags, di_DiskInfo *diptr)
+convertMountOptions (long flags, diDiskInfo_t *diptr)
 #else
 convertMountOptions (flags, diptr)
     long          flags;
-    di_DiskInfo   *diptr;
+    diDiskInfo_t   *diptr;
 #endif
 {
 #if defined (MNT_RDONLY)
@@ -2213,13 +2213,13 @@ convertMountOptions (flags, diptr)
 
 static void
 #if _proto_stdc
-convertNFSMountOptions (long flags, long wsize, long rsize, di_DiskInfo *diptr)
+convertNFSMountOptions (long flags, long wsize, long rsize, diDiskInfo_t *diptr)
 #else
 convertNFSMountOptions (flags, wsize, rsize, diptr)
     long          flags;
     long          wsize;
     long          rsize;
-    di_DiskInfo   *diptr;
+    diDiskInfo_t   *diptr;
 #endif
 {
 #if defined (NFSMNT_SOFT)
@@ -2295,10 +2295,10 @@ trimChar (str, ch)
 #if ! defined (DI_GETDISKINFO_DEF)
 void
 #  if _proto_stdc
-di_getDiskInfo (di_DiskInfo **diskInfo, int *diCount)
+di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
 #  else
 di_getDiskInfo (diskInfo, diCount)
-    di_DiskInfo **diskInfo;
+    diDiskInfo_t **diskInfo;
     int *diCount;
 #  endif
 {
@@ -2309,10 +2309,10 @@ di_getDiskInfo (diskInfo, diCount)
 
 void
 # if _proto_stdc
-di_testRemoteDisk (di_DiskInfo *diskInfo)
+di_testRemoteDisk (diDiskInfo_t *diskInfo)
 # else
 di_testRemoteDisk (diskInfo)
-    di_DiskInfo *diskInfo;
+    diDiskInfo_t *diskInfo;
 # endif
 {
     if (strcmp (diskInfo->fsType, "nfs") == 0 ||
