@@ -1,7 +1,7 @@
 /*
-$Id: getopt.c,v 1.6 2005-07-25 10:31:03-07 bll Exp $
-$Source: /home/bll/DI/RCS/getopt.c,v $
-Copyright 1994-2004 Brad Lanam, Walnut Creek, CA
+$Id: getopt.c,v 1.7 2007-05-30 10:26:46-07 bll Exp $
+$Source: /export/home/bll/DI/RCS/getopt.c,v $
+Copyright 1994-2007 Brad Lanam, Walnut Creek, CA
 */
 
 #include "config.h"
@@ -10,7 +10,7 @@ Copyright 1994-2004 Brad Lanam, Walnut Creek, CA
 
 /*
  *
- * $Id: getopt.c,v 1.6 2005-07-25 10:31:03-07 bll Exp $
+ * $Id: getopt.c,v 1.7 2007-05-30 10:26:46-07 bll Exp $
  *
  * getopt - get option letter from argv
  *
